<?php
/**
* @version		4.0
* @author		Michael A. Gilkes (michael@valorapps.com)
* @copyright	Michael Albert Gilkes
* @license		GNU/GPLv2
*/

/*

Easy Google Analytics for Joomla!
Copyright (C) 2011-2023  Michael Albert Gilkes

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

*/
/**
 * Links for later reference:
 * https://support.google.com/analytics/answer/12002338#zippy=%2Cset-up-your-google-tag-from-google-ads-instructions%2Cuse-the-google-tag-found-on-your-website-recommended%2Cuse-a-google-tag-you-already-have%2Cinstall-a-google-tag
 * https://support.google.com/google-ads/answer/12131703#zippy=
 * https://support.google.com/tagmanager/answer/6102821
 * https://support.google.com/tagmanager/answer/6103576?hl=en&ref_topic=3441530
 * https://support.google.com/tagmanager/answer/6103696?hl=en&ref_topic=3441530#zippy=%2Cwhat-is-a-tag%2Cwhat-is-an-account%2Cwhat-is-a-container%2Coptional-add-more-containers-to-your-account
 * https://support.google.com/tagmanager/answer/7582054
 * https://support.google.com/tagmanager/answer/12974036?hl=en&ref_topic=3441530
 * https://measureschool.com/google-tag-manager-vs-global-site-tag/
 * 
 ****************************************************/

// no direct access
defined('_JEXEC') or die('Restricted access');

use Joomla\CMS\Plugin\CMSPlugin;
use Joomla\CMS\Factory;

class plgSystemEasyGoogleAnalytics extends CMSPlugin
{
    /**
     * Load the language file on instantiation.
     */
    protected $autoloadLanguage = true;

    /**
     * Add Javascript to head tag
     */
	public function onBeforeCompileHead()
	{
		// check whether plugin has been unpublished
		if ($this->params->get('enabled', 1))
		{
			//do we exclude the admin?
			if ($this->params->get('ega_admin') == 1)
			{
				//check to see if we are in the front-end or back-end
				if(Factory::getApplication()->isClient('administrator'))
				{
					return; //leave since we are in the back-end. bye.
				}
			}
			
			//get the parameters
			$measurementId = $this->params->get('measurement_id');
			$noVisitors = $this->params->get('ega_no_visitors');
			$noCookie = $this->params->get('ega_no_cookie');
			$noRemarketing = $this->params->get('ega_no_remarketing');
			
			//handle the completed asynchronous tracking code
			$this->customTrackingCode($measurementId, $noVisitors, $noCookie, $noRemarketing);
		}
	}
	
	/**
	* method that composes the Google Tag and adds it to the HEAD of the page
	*
	* Reference: https://support.google.com/analytics/answer/12002338
	*/
	protected function customTrackingCode($measurementId, $noVisitors, $noCookie, $noRemarketing)
	{
		//Specify the src
		$src = "https://www.googletagmanager.com/gtag/js?id=".$measurementId;
		
		//Add the Google GTAG script
		Factory::getDocument()->addScript($src, [], array('async' => true));

		//setup optional features
		$optional = "";
		if ($noVisitors) {
			$optional.= "'send_page_view': false";
		}
		if ($noCookie) {
			if (!empty($optional)) {
				$optional.= ",";
			}
			$optional.= "'conversion_linker': false";
		}
		if (!empty($optional)) {
			$optional = ',{'.$optional.'}';
		}

		//Add the Google GTAG code
		$script = "\n".'window.dataLayer = window.dataLayer || [];';
		$script.= "\n".'function gtag(){dataLayer.push(arguments);}';
		if ($noRemarketing) {
			$script.= "\n"."gtag('set', 'allow_ad_personalization_signals', false);";
		}
		$script.= "\n"."gtag('js', new Date());";
		$script.= "\n"."gtag('config', '".$measurementId."'".$optional.");";
		
		//add the javascript to the head of the html document
		Factory::getDocument()->addScriptDeclaration($script);
	}
}